# Charts 📈

```{note} 
This page shows only the most recently added charts. To search all charts, use the search function in the top-right or browse by topic or data source in the navigation bar on the left.
```


```{postlist} 500
:list-style: circle
:category:
:date: "%Y-%m-%d"
:format: "{title}"
:excerpts:
:sort:
```